import React from 'react'
import ReactDOM from 'react-dom/client'
import './index.css'
import { useState } from 'react';

const GameStudioPage = () => {
  const [hoveredGame, setHoveredGame] = useState<number | null>(null);

  const games = [
    {
      title: "Asteroid's Revenge",
      description: "Roar through the asteroid field in this space-themed highscore game powered by Godot engine.",
      genre: "Bullet-Hell",
      weblink: "https://ragebreaker.itch.io/asteroids-revenge",
      image: 'https://img.itch.zone/aW1nLzE1MTMwODI5LnBuZw==/315x250%23c/DhOtXb.png'
    },
    {
      title: "Flappy Birby",
      description: "An endless retro remake of Flappy Bird in landscape mode.",
      genre: "Arcade",
      weblink: "https://ragebreaker.itch.io/flappy-birby",
      image: 'https://img.itch.zone/aW1nLzE0OTQzNDA1LnBuZw==/315x250%23c/E3p5hs.png'
    },
    {
      title: "Furry Runner",
      description: "An endless fast-paced runner where furries escape anti-furry groups, dodging spikes and rocks.",
      genre: "Action",
      weblink: "https://ragebreaker.itch.io/furry-runner",
      image: "https://img.itch.zone/aW1nLzE0OTI2ODkzLnBuZw==/315x250%23c/nDchXx.png"
    },
    {
      title: "Just Keep Chasing",
      description: "An roguelite where u are a nanobot in a human body, trying to kill of viruses (theme)",
      genre: "Roguelike",
      weblink: "https://codeberg.org/mlmstudios/just-keep-chasing",
      image: "https://codeberg.org/mlmstudios/just-keep-chasing/raw/commit/f8c109c249d27d073d6e71005202a9045071fbf8/assets/sprites/player.png"
    }
  ];

  return (
    <div className="min-h-screen bg-slate-900 text-white">
      {/* Hero Section */}
      <header className="py-16 px-4 text-center bg-gradient-to-b from-violet-900 to-slate-900">
        <h1 className="text-4xl md:text-6xl font-bold mb-4">MLM Studios</h1>
        <p className="text-xl md:text-2xl text-slate-300 mb-8">Open Source Indie Game Development</p>
        <button className="bg-violet-600 hover:bg-violet-700 transition-colors px-8 py-3 rounded-lg font-semibold">
        <a 
            href="https://ragebreaker.itch.io" 
            target="_blank" 
            rel="noopener noreferrer"
            className="text-white"
        >
            Explore Our Games
        </a>
        </button>
      </header>

      {/* Games Grid */}
      <main className="max-w-7xl mx-auto px-4 py-16">
        <h2 className="text-3xl font-bold mb-12 text-center">Our Games</h2>
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-8">
          {games.map((game, index) => (
            <div
              key={game.title}
              className="bg-slate-800 rounded-xl p-6 transition-transform duration-300 hover:scale-105"
              onMouseEnter={() => setHoveredGame(index)}
              onMouseLeave={() => setHoveredGame(null)}
            >
              <div className="bg-gradient-to-br from-violet-600 to-slate-700 rounded-xl mb-4">
                <div><img src={game.image} alt="Game Art" className="bg-slate-200 border-2 border-dashed rounded-xl w-full h-48"/></div>
              </div>
              <div className="space-y-2">
                <span className="text-violet-400 text-sm font-medium">{game.genre}</span>
                <h3 className="text-xl font-bold">{game.title}</h3>
                <p className="text-slate-400 text-sm">{game.description}</p>
                <button className="mt-4 w-full bg-violet-600 hover:bg-violet-700 transition-colors py-2 rounded-lg font-medium">
                    <a 
                        href={game.weblink} 
                        target="_blank" 
                        rel="noopener noreferrer"
                        className="text-white"
                    >
                        Learn More
                    </a>
                </button>
              </div>
            </div>
          ))}
        </div>
      </main>

      {/* Studio Info Section */}
      <section className="bg-slate-800 py-16 px-4 mt-16">
        <div className="max-w-7xl mx-auto text-center">
          <h2 className="text-3xl font-bold mb-6">Join Our Community</h2>
          <p className="text-slate-300 mb-8 max-w-2xl mx-auto">
            Stay updated with our latest releases, development updates, and exclusive content by joining our growing community of gamers.
          </p>
          <div className="flex justify-center gap-4">
            <button className="bg-violet-600 hover:bg-violet-700 transition-colors px-6 py-2 rounded-lg font-medium">
              Discord
            </button>
            <button className="bg-slate-700 hover:bg-slate-600 transition-colors px-6 py-2 rounded-lg font-medium">
              Newsletter
            </button>
          </div>
        </div>
      </section>

      {/* Footer */}
      <footer className="bg-slate-900 py-8 px-4 text-center text-slate-400">
        <div className="max-w-7xl mx-auto">
          <p>© 2023 MLM Studios. All rights reserved.</p>
        </div>
      </footer>
    </div>
  );
};

ReactDOM.createRoot(document.getElementById('root')!).render(
    <React.StrictMode>
      <GameStudioPage />
    </React.StrictMode>
);

export default GameStudioPage;